
# Cogneato API

API for Cogneato, an experimental optimizer.

Optimize noisy metrics over continuous, categorical, and ordinal parameters.

See:  
 - https://cogneato.xyz
 - https://github.com/cogneato-xyz/cogneato-api
 
